@@ -10,21 +10,27 @@ from python_search.configuration.loader import ConfigurationLoader
 from python_search.next_item_predictor.inference.input import ModelInput
 from python_search.next_item_predictor.v2.previous_key_feature import PreviousKey
 from python_search.search.models import PythonSearchMLFlow
-from python_search.next_item_predictor.features.entry_embeddings import InferenceEmbeddingsLoader
-from python_search.next_item_predictor.features.entry_embeddings.entry_embeddings import \
-    create_key_indexed_embedding
+from python_search.next_item_predictor.features.entry_embeddings import (
+    InferenceEmbeddingsLoader,
+)
+from python_search.next_item_predictor.features.entry_embeddings.entry_embeddings import (
+    create_key_indexed_embedding,
+)
 from python_search.next_item_predictor.model_interface import ModelInterface
 
+
 def number_of_same_words(key1, key2) -> int:
     count = 0
-    for i in key1.split(' '):
-        for j in key2.split(' '):
+    for i in key1.split(" "):
+        for j in key2.split(" "):
             if i == j:
-                count+=1
+                count += 1
     return count
 
+
 def number_of_same_words_from_row(row):
-    return number_of_same_words(row['key_performed'], row['key'])
+    return number_of_same_words(row["key_performed"], row["key"])
+
 
 class NextItemModelV2(ModelInterface):
     PRODUCTION_RUN_ID = "bc55a9e7acb64f6aa05b63158bad9dc6"
@@ -41,80 +47,114 @@ class NextItemModelV2(ModelInterface):
         print("Building dataset v2")
 
         self._ranking_df = self._get_ranking_entries_dataset()
-        print(f'Rank entries total: {self._ranking_df.count()}')
-
+        print(f"Rank entries total: {self._ranking_df.count()}")
 
         self._performed_df = self._get_performed_entries_dataset()
         # decrement the position of the performed entries, it starts at 1 there but at the ranking event at 0
 
-        self._ranking_df = self._remove_rankings_without_performed_entries(self._ranking_df, self._performed_df)
+        self._ranking_df = self._remove_rankings_without_performed_entries(
+            self._ranking_df, self._performed_df
+        )
 
         # remove entries that contain the performed key from ranking_df
-        performed_keys = self._performed_df.select(F.col('key').alias('performed_key'), F.col('uuid').alias('performed_uuid'),
-                                             F.col('position').alias('performed_position'))
-
-        self._ranking_df = self._ranking_df.join(performed_keys, on=[ performed_keys.performed_uuid == self._ranking_df.uuid,
-                                                     performed_keys.performed_position == self._ranking_df.position],
-                                 how='left_anti')
+        performed_keys = self._performed_df.select(
+            F.col("key").alias("performed_key"),
+            F.col("uuid").alias("performed_uuid"),
+            F.col("position").alias("performed_position"),
+        )
 
+        self._ranking_df = self._ranking_df.join(
+            performed_keys,
+            on=[
+                performed_keys.performed_uuid == self._ranking_df.uuid,
+                performed_keys.performed_position == self._ranking_df.position,
+            ],
+            how="left_anti",
+        )
 
         self._ranking_df = self._add_share_words_count_as_ranking_label()
 
-
         # add performed entries to ranking_df
-        print('Ranking df schema:')
+        print("Ranking df schema:")
         self._ranking_df.printSchema()
-        print('Performed df schema:')
+        print("Performed df schema:")
         self._performed_df.printSchema()
 
         unioned = self._ranking_df.union(self._performed_df)
-        unioned = unioned.withColumn('timestamp', F.unix_timestamp('datetime'))
+        unioned = unioned.withColumn("timestamp", F.unix_timestamp("datetime"))
 
         window = Window.orderBy(F.col("key"))
-        unioned = unioned.withColumn(
-            "entry_number", F.row_number().over(window)
-        )
+        unioned = unioned.withColumn("entry_number", F.row_number().over(window))
 
         # prepare result for returning
         # select only relevant columns
-        dataset = unioned.select('entry_number',  'key', 'uuid', 'datetime', 'timestamp', 'position', 'label')
+        dataset = unioned.select(
+            "entry_number", "key", "uuid", "datetime", "timestamp", "position", "label"
+        )
         # sort dataframe in a readable way
-        dataset = dataset.sort(['uuid', 'timestamp', 'position'], ascending=[True, False, True])
+        dataset = dataset.sort(
+            ["uuid", "timestamp", "position"], ascending=[True, False, True]
+        )
 
-        dfp = PreviousKey().get_previous_n(n=2).select('uuid', 'previous_1_key', 'previous_2_key')
-        dataset = dataset.join(dfp, on=dfp.uuid == dataset.uuid, how='left')
+        dfp = (
+            PreviousKey()
+            .get_previous_n(n=2)
+            .select("uuid", "previous_1_key", "previous_2_key")
+        )
+        dataset = dataset.join(dfp, on=dfp.uuid == dataset.uuid, how="left")
 
         if debug:
             dataset.show(n=10, truncate=False)
-        dataset = dataset.withColumnRenamed('previous_1_key', 'previous_key')
-        dataset = dataset.withColumnRenamed('previous_2_key', 'previous_previous_key')
+        dataset = dataset.withColumnRenamed("previous_1_key", "previous_key")
+        dataset = dataset.withColumnRenamed("previous_2_key", "previous_previous_key")
 
         return dataset
 
     def _remove_rankings_without_performed_entries(self, ranking_df, performed_df):
         # remove ranks without performed keys in it
-        performed_uuids = performed_df.select('uuid').withColumnRenamed('uuid', 'performed_uuid')
-        ranking_df = performed_uuids.join(ranking_df, on=performed_uuids.performed_uuid == self._ranking_df.uuid, how='left')
-        ranking_df = ranking_df.drop('performed_uuid')
-        ranking_df = ranking_df.withColumn('position', F.col('position').cast('int'))
-        print(f'Ranks entries with executed item: {ranking_df.count()}')
+        performed_uuids = performed_df.select("uuid").withColumnRenamed(
+            "uuid", "performed_uuid"
+        )
+        ranking_df = performed_uuids.join(
+            ranking_df,
+            on=performed_uuids.performed_uuid == self._ranking_df.uuid,
+            how="left",
+        )
+        ranking_df = ranking_df.drop("performed_uuid")
+        ranking_df = ranking_df.withColumn("position", F.col("position").cast("int"))
+        print(f"Ranks entries with executed item: {ranking_df.count()}")
         return ranking_df
 
     def _add_share_words_count_as_ranking_label(self):
         ## add number of same words as temporary feature to update the label
-        performed_key_and_uuid = self._performed_df.select(F.col('uuid').alias('uuid_performed'), F.col('key').alias('key_performed'))
-        same_words_df = performed_key_and_uuid.join(self._ranking_df, on=performed_key_and_uuid.uuid_performed == self._ranking_df.uuid, how='left')
+        performed_key_and_uuid = self._performed_df.select(
+            F.col("uuid").alias("uuid_performed"), F.col("key").alias("key_performed")
+        )
+        same_words_df = performed_key_and_uuid.join(
+            self._ranking_df,
+            on=performed_key_and_uuid.uuid_performed == self._ranking_df.uuid,
+            how="left",
+        )
         udf_f = udf(number_of_same_words_from_row)
-        same_words_df = same_words_df.withColumn('share_words_count', udf_f(struct([same_words_df[x] for x in same_words_df.columns])))
-        self._ranking_df = same_words_df.drop('uuid_performed').drop('key_performed')
+        same_words_df = same_words_df.withColumn(
+            "share_words_count",
+            udf_f(struct([same_words_df[x] for x in same_words_df.columns])),
+        )
+        self._ranking_df = same_words_df.drop("uuid_performed").drop("key_performed")
         # add same words as criteria for label
-        return self._ranking_df.withColumn('label', F.when(F.col('share_words_count') > 0, 2).otherwise(F.col('label')))
+        return self._ranking_df.withColumn(
+            "label", F.when(F.col("share_words_count") > 0, 2).otherwise(F.col("label"))
+        )
 
     def _decrement_entry_position(self, performed_df):
-        print('Decrementing performed entries position')
-        performed_df = performed_df.withColumn('position', F.col('position').cast('int'))
-        performed_df = performed_df.withColumn('position', F.col('position') - 1)
-        performed_df = performed_df.withColumn('position', F.col('position').cast('String'))
+        print("Decrementing performed entries position")
+        performed_df = performed_df.withColumn(
+            "position", F.col("position").cast("int")
+        )
+        performed_df = performed_df.withColumn("position", F.col("position") - 1)
+        performed_df = performed_df.withColumn(
+            "position", F.col("position").cast("String")
+        )
 
         return performed_df
 
@@ -125,15 +165,15 @@ class NextItemModelV2(ModelInterface):
         """
         import pyspark.sql.functions as F
         from python_search.events.ranking_generated import RankingGeneratedDataset
+
         rg = RankingGeneratedDataset().load()
         rg = rg.withColumn("datetime", F.from_unixtime("timestamp"))
 
-        base_entries = rg.select(F.posexplode("ranking").alias('position', 'entry'), "uuid", 'datetime').select(F.col("entry").alias('key'),
-                                                                                                                "position",
-                                                                                                                "uuid",
-                                                                                                                "datetime")
+        base_entries = rg.select(
+            F.posexplode("ranking").alias("position", "entry"), "uuid", "datetime"
+        ).select(F.col("entry").alias("key"), "position", "uuid", "datetime")
         # entries form ranking generated by default contain not executed things
-        return base_entries.withColumn('label', F.lit(0))
+        return base_entries.withColumn("label", F.lit(0))
 
     def _get_performed_entries_dataset(self) -> DataFrame:
         """
@@ -142,20 +182,24 @@ class NextItemModelV2(ModelInterface):
         """
         from python_search.events.run_performed.dataset import EntryExecutedDataset
         import pyspark.sql.functions as F
-        performed_entries = EntryExecutedDataset().load_clean()
-        performed_entries = performed_entries.filter("rank_uuid IS NOT NULL and rank_position IS NOT NULL").select(
-            F.col("key"), F.col("rank_position").alias('position'), F.col("rank_uuid").alias('uuid'),
-            F.col("timestamp").alias('datetime'))
-        performed_entries = performed_entries.withColumn('label', F.lit(5))
 
-        performed_entries = performed_entries.withColumn('share_words_count', F.lit(0))
+        performed_entries = EntryExecutedDataset().load_clean()
+        performed_entries = performed_entries.filter(
+            "rank_uuid IS NOT NULL and rank_position IS NOT NULL"
+        ).select(
+            F.col("key"),
+            F.col("rank_position").alias("position"),
+            F.col("rank_uuid").alias("uuid"),
+            F.col("timestamp").alias("datetime"),
+        )
+        performed_entries = performed_entries.withColumn("label", F.lit(5))
+
+        performed_entries = performed_entries.withColumn("share_words_count", F.lit(0))
         performed_entries = self._decrement_entry_position(performed_entries)
 
         return performed_entries
 
-    def transform_collection(
-            self, dataset: DataFrame
-    ) -> Tuple[np.ndarray, np.ndarray]:
+    def transform_collection(self, dataset: DataFrame) -> Tuple[np.ndarray, np.ndarray]:
         """
         Returns X and Y
         :param dataset:
@@ -191,7 +235,7 @@ class NextItemModelV2(ModelInterface):
         return X, Y
 
     def _NormalizeData(self, data):
-        """normalize a value between 0 and 1 """
+        """normalize a value between 0 and 1"""
         return (data - np.min(data)) / (np.max(data) - np.min(data))
 
     def transform_single(self, inference_input: dict) -> np.ndarray:
@@ -200,9 +244,10 @@ class NextItemModelV2(ModelInterface):
         :param inference_input:
         :return:
         """
-        inference_input_obj: ModelInput = inference_input['inference_input']
-        all_keys = inference_input['all_keys']
-        from datetime import datetime;
+        inference_input_obj: ModelInput = inference_input["inference_input"]
+        all_keys = inference_input["all_keys"]
+        from datetime import datetime
+
         timestamp = int(datetime.now().timestamp())
 
         previous_key_embedding = self.inference_embeddings.get_embedding_from_key(
@@ -240,10 +285,7 @@ class NextItemModelV2(ModelInterface):
     def get_run_id(self):
         return self.PRODUCTION_RUN_ID
 
-
-    def _create_embeddings_training_dataset(
-        self, dataset
-    ) -> Dict[str, np.ndarray]:
+    def _create_embeddings_training_dataset(self, dataset) -> Dict[str, np.ndarray]:
         """
         create embeddings with all training keys and keep them in memory
         """
@@ -264,5 +306,4 @@ class NextItemModelV2(ModelInterface):
         for i in previous_2_keys:
             all_keys.append(i.previous_previous_key)
 
-
         return create_key_indexed_embedding(all_keys)
